#if defined(HAVE_CONFIG_H)
#  include "config.h"
#endif

#include <glib.h>

#include <stdio.h>

#include <sstream>

#include "gql++/object.h"
#include "gql++/driver.h"
#include "gql++/exception.h"
#include "gql++/warning.h"

namespace GQL
{

Connection::~Connection()
{
}

SQLObject *Connection::create_object()
{
  return new BasicSQLObject();
}

SQLObject *Connection::create_blob()
{
  throw SQLException("Driver doesn't support BLOBs");
}

void Connection::destroy_blob(SQLObject *blob)
{
  throw SQLException("Driver doesn't support BLOBs");
}


}
